/**
 * Copyright 2010-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.auditreport.api;

import java.io.Serializable;


/**
 * Defines an ID used to track calls across different components.
 * @author Florent Benoit
 */
public interface IAuditID extends Serializable {

    /**
     * @return the parent ID.
     */
    String getParentID();

    /**
     * @return the full ID.
     */
    String getID();

    /**
     * @return the local ID.
     */
    String getLocalID();

    /**
     * A call is done on this ID, needs to increment.
     */
    void increment();

    /**
     * Generate a new ID.
     */
    void generate();

    /**
     * Sets the parent ID.
     * @param parentID the given parent ID
     */
    void setParentID(final String parentID);

}
