/**
 * Copyright 2010-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.auditreport.api;


/**
 * Interface used to provide the current ID.
 * @author Florent Benoit
 */
public interface ICurrentInvocationID {

    /**
     * Associates the given audit ID to the current thread.
     * @param auditID the ID to associate to the current thread.
     * @return the previous audit ID.
     */
    IAuditID setAuditID(final IAuditID auditID);

    /**
     * Gets the current audit ID.
     * @return the ID to associate to the current thread
     */
    IAuditID getAuditID();

    /**
     * Initialize a new Audit ID with an optional value.
     * @param id the initial value
     */
    void init(final IAuditID id);

    /**
     * Generate a new ID and return the previously set.
     * @return the previous ID.
     */
    IAuditID newInvocation();

}
