/**
 * Copyright 2010-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.auditreport.api;

/**
 * Interface which describing an encodable and displayable object.
 * @author Vincent Michaud
 */
public interface IDisplayableType<TypeObject> extends IEncodableType<TypeObject> {

    /**
     * Convert an encoded string to a displayable string.
     * @param encodedString The encoded string
     * @return A string representation of the object, or a list of string (in
     *         case of array, or complex objects) Each string must not contain
     *         new line characters. Returning a list of string can be used for
     *         this. Also, each string must not begin with a sequence of space.
     */
    Object encodedToDisplayable(final String encodedString);

    /**
     * Convert a displayable string to an encoded string.
     * @param strObject The displayble object. The object can be a string or a
     *        list of string (in case of array, or complex objects). Each string
     *        does not contain new line characters.
     * @return The new object
     */
    String displayableToEncoded(final Object strObject);
}
