/**
 * Copyright 2010-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.auditreport.impl;

import java.io.Serializable;
import java.util.UUID;

import org.ow2.util.auditreport.api.IAuditID;

/**
 * Implementation of the Audit ID.
 * @author Florent Benoit
 */
public class AuditIDImpl implements IAuditID, Serializable {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 3855603875318289890L;

    /**
     * Parent ID.
     */
    private String parentID = "";

    /**
     * Local count.
     */
    private long localCount = 0L;

    /**
     * ID.
     */
    private String id = "";

    /**
     * Default Constructor.
     */
    public AuditIDImpl() {
    }

    /**
     * Creates an Audit with the given id.
     * @param auditId the given ID
     */
    public AuditIDImpl(final String auditId) {
        this();

        // Split parent and local
        String[] ids = auditId.split(":");
        this.parentID = ids[0];
        String localID = ids[1];
        // there is an ID in the message, store it
        String[] clientID = localID.split("/");
        this.id = clientID[0];
        this.localCount = Integer.valueOf(clientID[1]).longValue();
    }

    /**
     * @return the parent ID.
     */
    public String getParentID() {
        return parentID;
    }

    /**
     * @return the full ID.
     */
    public String getID() {
        return getParentID() + ":" + getLocalID();
    }

    /**
     * @return the local ID.
     */
    public String getLocalID() {
        return id + "/" + localCount;
    }

    /**
     * A call is done on this ID, needs to increment.
     */
    public void increment() {
        localCount++;
    }

    /**
     * Generate a new ID.
     */
    public void generate() {
        this.id = UUID.randomUUID().toString();
    }

    /**
     * Sets the parent ID.
     * @param parentID the given parent ID
     */
    public void setParentID(final String parentID) {
        this.parentID = parentID;
    }

}
