/**
 * Copyright 2010-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.auditreport.impl;

import org.ow2.util.auditreport.impl.util.ObjectEncoder;

/**
 * @author Mathieu ANCELIN
 */
public class GenericAuditReport extends BasicAuditReport {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 3417852553275676389L;

    /**
     * Id of the report.
     */
    private static long generatedID = ZERO;

    /**
     * The id number of the report.
     */
    private long reportID = ZERO;

    /**
     * ID used to track calls.
     */
    private String keyID = null;

    /**
     * The name of the concerned bean.
     */
    private String beanName = EMPTY_STRING;

    /**
     * The stacktrace of the current thread.
     */
    private Object[] methodStackTrace = null;

    /**
     * The free memory used before the call.
     */
    private int freeMemoryBefore = ZERO;

    /**
     * The total memory used before the call.
     */
    private int totalMemoryBefore = ZERO;

    /**
     * The free memory used after the call.
     */
    private int freeMemoryAfter = ZERO;

    /**
     * The total memory used after the call.
     */
    private int totalMemoryAfter = ZERO;

    /**
     * The sweepmark time of the GC.
     */
    private long sweepMarkTime = ZERO;

    /**
     * the scavengeTime of the GC.
     */
    private long scavengeTime = ZERO;

    /**
     * The security user.
     */
    private String user = EMPTY_STRING;

    /**
     * The security roles.
     */
    private String roles = EMPTY_STRING;


    static {
        // Register fields "Object[] methodStackTrace".
        ObjectEncoder.registerField(GenericAuditReport.class, "methodStackTrace", EncodingType.OBJECTTABLE);
    }

    /**
     * The default constructor.
     */
    public GenericAuditReport() {
        if (generatedID == Long.MAX_VALUE) {
            generatedID = 0;
        }
        generatedID++;
        this.reportID = generatedID;
    }

    /**
     * @return the beanName
     */
    public String getBeanName() {
        return beanName;
    }

    /**
     * @param beanName the beanName to set
     */
    public void setBeanName(final String beanName) {
        this.beanName = beanName;
    }

    /**
     * @return the methodStackTrace
     */
    public Object[] getMethodStackTrace() {
        return methodStackTrace;
    }

    /**
     * @param methodStackTrace the methodStackTrace to set
     */
    public void setMethodStackTrace(final Object[] methodStackTrace) {
        this.methodStackTrace = methodStackTrace;
    }

    /**
     * @return the freeMemoryBefore
     */
    public int getFreeMemoryBefore() {
        return freeMemoryBefore;
    }

    /**
     * @param freeMemoryBefore the freeMemoryBefore to set
     */
    public void setFreeMemoryBefore(final int freeMemoryBefore) {
        this.freeMemoryBefore = freeMemoryBefore;
    }

    /**
     * @return the totalMemoryBefore
     */
    public int getTotalMemoryBefore() {
        return totalMemoryBefore;
    }

    /**
     * @param totalMemoryBefore the totalMemoryBefore to set
     */
    public void setTotalMemoryBefore(final int totalMemoryBefore) {
        this.totalMemoryBefore = totalMemoryBefore;
    }

    /**
     * @return the freeMemoryAfter
     */
    public int getFreeMemoryAfter() {
        return freeMemoryAfter;
    }

    /**
     * @param freeMemoryAfter the freeMemoryAfter to set
     */
    public void setFreeMemoryAfter(final int freeMemoryAfter) {
        this.freeMemoryAfter = freeMemoryAfter;
    }

    /**
     * @return the totalMemoryAfter
     */
    public int getTotalMemoryAfter() {
        return totalMemoryAfter;
    }

    /**
     * @param totalMemoryAfter the totalMemoryAfter to set
     */
    public void setTotalMemoryAfter(final int totalMemoryAfter) {
        this.totalMemoryAfter = totalMemoryAfter;
    }

    /**
     * @return the sweepMarkTime
     */
    public long getSweepMarkTime() {
        return sweepMarkTime;
    }

    /**
     * @param sweepMarkTime the sweepMarkTime to set
     */
    public void setSweepMarkTime(final long sweepMarkTime) {
        this.sweepMarkTime = sweepMarkTime;
    }

    /**
     * @return the scavengeTime
     */
    public long getScavengeTime() {
        return scavengeTime;
    }

    /**
     * @param scavengeTime the scavengeTime to set
     */
    public void setScavengeTime(final long scavengeTime) {
        this.scavengeTime = scavengeTime;
    }

    /**
     * @return the roles
     */
    public String getRoles() {
        return roles;
    }

    /**
     * @param roles the roles to set
     */
    public void setRoles(final String roles) {
        this.roles = roles;
    }

    /**
     * @return the user
     */
    public String getUser() {
        return user;
    }

    /**
     * @param user the user to set
     */
    public void setUser(final String user) {
        this.user = user;
    }

    /**
     * @return the memory used before the call.
     */
    public int getUsedMemoryBefore() {
        return this.getTotalMemoryBefore() - this.getFreeMemoryBefore();
    }

    /**
     * @return the memory used after the call.
     */
    public int getUsedMemoryAfter() {
        return this.getTotalMemoryAfter() - this.getFreeMemoryAfter();
    }

    /**
     * @return the audit report id number.
     */
    public long getReportID() {
        return reportID;
    }

    /**
     * @param reportID the audit report id number.
     */
    public void setReportID(final long reportID) {
        this.reportID = reportID;
    }

    /**
     * @return the key id.
     */
    public String getKeyID() {
        return keyID;
    }

    /**
     * @param keyID the key id.
     */
    public void setKeyID(final String keyID) {
        this.keyID = keyID;
    }
}
