/**
 * Copyright 2010-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.auditreport.impl;

import org.ow2.util.auditreport.impl.util.ObjectEncoder;


/**
 * An audit report for lifecycle events.
 * @author Mathieu ANCELIN
 */
public class LifeCycleAuditReport extends GenericAuditReport {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 7236678193896016411L;

    /**
     * Steps of a bean's lifecycle.
     */
    public static enum STEP {
        STARTING, STARTED, STOPPING, STOPPED
    }

    /**
     * The step of the bean's lifecycle.
     */
    private STEP step = null;

    static {
        ObjectEncoder.registerField(LifeCycleAuditReport.class, "step", EncodingType.LCENUM);
    }

    /**
     * the default constructor.
     */
    public LifeCycleAuditReport() {
        super();
    }

    /**
     * the constructor of the report.
     * @param requestTimeStampParam the timestamp of the report.
     * @param beanNameParam the name of the bean.
     * @param stepParam the step of the report.
     * @param currentThreadParam the current thread.
     * @param freeMemoryBeforeParam the free memory before the event.
     * @param totalMemoryBeforeParam the total memeory before the event.
     * @param freeMemoryAfterParam the free memory after the event.
     * @param totalMemoryAfterParam the total memory after the event.
     */
    public LifeCycleAuditReport(final long requestTimeStampParam, final String beanNameParam, final STEP stepParam,
            final Thread currentThreadParam, final int freeMemoryBeforeParam, final int totalMemoryBeforeParam,
            final int freeMemoryAfterParam, final int totalMemoryAfterParam) {
        super();
        setBeanName(beanNameParam);
        setRequestTimeStamp(requestTimeStampParam);
        setMethodStackTrace(currentThreadParam.getStackTrace());
        setFreeMemoryBefore(freeMemoryBeforeParam);
        setTotalMemoryBefore(totalMemoryBeforeParam);
        setFreeMemoryAfter(freeMemoryAfterParam);
        setTotalMemoryAfter(totalMemoryAfterParam);
        this.step = stepParam;
    }

    /**
     * Return the current step of the report.
     * @return the step of the report.
     */
    public STEP getStep() {
        return this.step;
    }

    /**
     * Set the step of this report.
     * @param theStep the step of this report.
     */
    public void setStep(final STEP theStep) {
        this.step = theStep;
    }
}
