/**
 * Copyright 2010-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.auditreport.impl.jmx;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.management.MBeanServer;
import javax.management.NotificationListener;
import javax.management.ObjectName;

/**
 * Thread waiting for JMX registration.
 * @author Mathieu ANCELIN
 */
public class ListeningChecker extends Thread {

    /**
     * Milliseconds to wait.
     */
    private static final int WAITING = 1000;

    /**
     * Logger of the class.
     */
    private Logger logger = Logger.getLogger(ListeningChecker.class.getName());

    /**
     * The JMX object to listen.
     */
    private ObjectName listening;

    /**
     * The listener associated with listening object.
     */
    private NotificationListener listener;

    /**
     * Running flag.
     */
    private boolean running = true;

    /**
     * MBean Server.
     */
    private MBeanServer jmxServer = null;

    /**
     * Constructor.
     * @param listening listened object associated with a listener.
     * @param listener the notification listener associated with listened
     *        object.
     */
    public ListeningChecker(final ObjectName listening, final NotificationListener listener) {
        this.listening = listening;
        this.listener = listener;
    }

    public void setJMXServer(final MBeanServer jmxServer) {
        this.jmxServer = jmxServer;
    }

    /**
     * Wait for the listened object presence in JMX.
     */
    @Override
    public void run() {
        logger.log(Level.INFO, "Waiting for " + listening.getCanonicalName() + " registration ...");
        while (running) {
            try {
                if (jmxServer != null) {
                    if (jmxServer.isRegistered(this.listening)) {
                        jmxServer.addNotificationListener(this.listening, this.listener, null, null);
                        logger.log(Level.INFO, listening.getCanonicalName() + " is now registered for audit logging.");
                        running = false;
                    }
                }
            } catch (Exception ex) {
                logger.log(Level.SEVERE, null, ex);
            }
            try {
                sleep(WAITING);
            } catch (InterruptedException ex) {
                logger.log(Level.SEVERE, null, ex);
            }
        }
    }
}
